@@ -34,7 +34,7 @@ log_levels =  OrderedDict((s.name,s) for s in sorted((
             , FAIL
             )))
 
-DEFAULT_LOG_LEVEL = WARN
+DEFAULT_LOG_LEVEL = INFO
 
 from fontbakery.reporters.terminal import TerminalReporter
 from fontbakery.reporters.serialize import SerializeReporter
@@ -116,6 +116,12 @@ def ArgumentParser(profile, profile_arg=True):
   argument_parser.add_argument('-L', '--list-checks', default=False, action='store_true',
                       help='List the checks available in the selected profile.')
 
+  argument_parser.add_argument('--dark-theme', default=False, action='store_true',
+                      help='Use a color theme with dark colors.')
+
+  argument_parser.add_argument('--light-theme', default=False, action='store_true',
+                      help='Use a color theme with light colors.')
+
   argument_parser.add_argument('--json', default=False, type=argparse.FileType('w'),
                       metavar= 'JSON_FILE',
                       help='Write a json formatted report to JSON_FILE.')
@@ -163,18 +169,16 @@ def ArgumentParser(profile, profile_arg=True):
                       )
   return argument_parser, values_keys
 
+
 class ArgumentParserError(Exception): pass
 
-class ThrowingArgumentParser(argparse.ArgumentParser):
-    def error(self, message):
-        raise ArgumentParserError(message)
 
 def get_module_from_file(filename):
   # filename = 'my/path/to/file.py'
   # module_name = 'file_module.file_py'
   module_name = 'file_module.{}'.format(os.path.basename(filename).replace('.', '_'))
-  profile = importlib.util.profile_from_file_location(module_name, filename)
-  module = importlib.util.module_from_profile(profile)
+  profile = importlib.util.spec_from_file_location(module_name, filename)
+  module = importlib.util.module_from_spec(profile)
   profile.loader.exec_module(module)
   return module
 
@@ -192,11 +196,14 @@ def get_module(name):
 
 def get_profile():
   """ Prefetch the profile module, to fill some holes in the help text."""
-  argument_parser = ThrowingArgumentParser(add_help=False)
-  argument_parser.add_argument('profile')
+  argument_parser, _ = ArgumentParser(Profile(), profile_arg=True)
+  # monkey patching will do here
+  def error(message): raise ArgumentParserError(message)
+  argument_parser.error = error
+
   try:
     args, _ = argument_parser.parse_known_args()
-  except ArgumentParserError:
+  except ArgumentParserError as e:
     # silently fails, the main parser will show usage string.
     return Profile()
   imported = get_module(args.profile)
@@ -220,14 +227,35 @@ def main(profile=None, values=None):
   argument_parser, values_keys = ArgumentParser(profile, profile_arg=add_profile_arg)
   args = argument_parser.parse_args()
 
+  # The default Windows Terminal just displays the escape codes. The argument
+  # parser above therefore has these options disabled.
+  if sys.platform == "win32":
+    args.no_progress = True
+    args.no_colors = True
+
+  from fontbakery.constants import NO_COLORS_THEME, DARK_THEME, LIGHT_THEME
+  if args.no_colors:
+    theme = NO_COLORS_THEME
+  else:
+    if args.light_theme:
+      theme = LIGHT_THEME
+    elif args.dark_theme:
+      theme = DARK_THEME
+    elif sys.platform == "darwin":
+      # The vast majority of MacOS users seem to use a light-background on the text terminal
+      theme = LIGHT_THEME
+    else:
+      # For orther systems like GNU+Linux and Windows, a dark terminal seems to be more common.
+      theme = DARK_THEME
+
+
   if args.list_checks:
     if args.loglevels == [PASS]: # if verbose:
-      from fontbakery.constants import WHITE_STR, CYAN_STR, BLUE_STR
       for section in profile._sections.values():
-        print(WHITE_STR.format("\nSection:") + " " + section.name)
+        print(theme["list-checks: section"]("\nSection:") + " " + section.name)
         for check in section._checks:
-          print(CYAN_STR.format(check.id) + "\n" +
-                BLUE_STR.format(f'"{check.description}"') + "\n")
+          print(theme["list-checks: check-id"](check.id) + "\n" +
+                theme["list-checks: description"](f'"{check.description}"') + "\n")
     else:
       for section_name, section in profile._sections.items():
         for check in section._checks:
@@ -257,19 +285,13 @@ def main(profile=None, values=None):
     argument_parser.print_usage()
     sys.exit(1)
 
-  # The default Windows Terminal just displays the escape codes. The argument
-  # parser above therefore has these options disabled.
-  if sys.platform == "win32":
-    args.no_progress = True
-    args.no_colors = True
-
   # the most verbose loglevel wins
   loglevel = min(args.loglevels) if args.loglevels else DEFAULT_LOG_LEVEL
   tr = TerminalReporter(runner=runner, is_async=False
                        , print_progress=not args.no_progress
                        , check_threshold=loglevel
                        , log_threshold=args.loglevel_messages or loglevel
-                       , usecolor=not args.no_colors
+                       , theme=theme
                        , collect_results_by=args.gather_by
                        , skip_status_report=None if args.show_sections\
                                                       else (STARTSECTION, ENDSECTION)
