@@ -1,5 +1,6 @@
 from fontbakery.callable import check
 from fontbakery.checkrunner import FAIL, PASS
+from fontbakery.message import Message
 # used to inform get_module_profile whether and how to create a profile
 from fontbakery.fonts_profile import profile_factory  # NOQA pylint: disable=unused-import
 
@@ -23,8 +24,11 @@ def com_google_fonts_check_whitespace_widths(ttFont):
   if space_width > 0 and space_width == nbsp_width:
     yield PASS, "Whitespace and non-breaking space have the same width."
   else:
-    yield FAIL, ("Whitespace and non-breaking space have differing width:"
-                 " Whitespace ({}) is {} font units wide, non-breaking space"
-                 " ({}) is {} font units wide. Both should be positive and the"
-                 " same.").format(space_name, space_width, nbsp_name,
-                                  nbsp_width)
+    yield FAIL,\
+          Message("different-widths",
+                  f"Whitespace and non-breaking space have differing width:"
+                  f" Whitespace ({space_name})"
+                  f" is {space_width} font units wide,"
+                  f" non-breaking space ({nbsp_name})"
+                  f" is {nbsp_width} font units wide."
+                  f" Both should be positive and the same.")
