@@ -36,8 +36,6 @@ OPENTYPE_PROFILE_CHECKS = [
     'com.adobe.fonts/check/name/postscript_name_consistency',
     'com.adobe.fonts/check/name/empty_records',
     'com.google.fonts/check/name/no_copyright_on_description',
-    'com.google.fonts/check/name/line_breaks',
-    'com.google.fonts/check/name/rfn',
     'com.google.fonts/check/name/match_familyname_fullfont',
     'com.google.fonts/check/varfont/regular_wght_coord',
     'com.google.fonts/check/varfont/regular_wdth_coord',
@@ -45,6 +43,9 @@ OPENTYPE_PROFILE_CHECKS = [
     'com.google.fonts/check/varfont/regular_ital_coord',
     'com.google.fonts/check/varfont/regular_opsz_coord',
     'com.google.fonts/check/varfont/bold_wght_coord',
+    'com.google.fonts/check/varfont/slnt_range',
+    'com.google.fonts/check/varfont/wght_valid_range',
+    'com.google.fonts/check/varfont/wdth_valid_range',
     'com.google.fonts/check/loca/maxp_num_glyphs',
     'com.adobe.fonts/check/cff2_call_depth',
     'com.adobe.fonts/check/cff_call_depth',
@@ -63,9 +64,8 @@ OPENTYPE_PROFILE_CHECKS = [
     'com.google.fonts/check/family_naming_recommendations',
     'com.google.fonts/check/maxadvancewidth',
     'com.google.fonts/check/points_out_of_bounds',
+    'com.google.fonts/check/glyf_non_transformed_duplicate_components',
     'com.google.fonts/check/all_glyphs_have_codepoints',
-    'com.google.fonts/check/monospace_max_advancewidth',
-    'com.google.fonts/check/wght_valid_range',
     'com.google.fonts/check/code_pages',
 ]
 
