@@ -5,7 +5,8 @@ from fontbakery.message import Message
 from fontbakery.fonts_profile import profile_factory # NOQA pylint: disable=unused-import
 
 profile_imports = [
-    ('.shared_conditions', ('vmetrics', ))
+    ('.shared_conditions', ('vmetrics', )),
+    ('.googlefonts_conditions', ('RIBBI_ttFonts', ))
 ]
 
 @check(
@@ -13,21 +14,21 @@ profile_imports = [
 )
 def com_google_fonts_check_family_panose_proportion(ttFonts):
   """Fonts have consistent PANOSE proportion?"""
-  failed = False
+  passed = True
   proportion = None
   for ttFont in ttFonts:
     if proportion is None:
       proportion = ttFont['OS/2'].panose.bProportion
     if proportion != ttFont['OS/2'].panose.bProportion:
-      failed = True
+      passed = False
 
-  if failed:
-    yield FAIL, ("PANOSE proportion is not"
-                 " the same accross this family."
-                 " In order to fix this,"
-                 " please make sure that the panose.bProportion value"
-                 " is the same in the OS/2 table of all of this family"
-                 " font files.")
+  if not passed:
+    yield FAIL,\
+          Message("inconsistency",
+                  "PANOSE proportion is not the same across this family."
+                  " In order to fix this, please make sure that"
+                  " the panose.bProportion value is the same"
+                  " in the OS/2 table of all of this family font files.")
   else:
     yield PASS, "Fonts have consistent PANOSE proportion."
 
@@ -37,21 +38,21 @@ def com_google_fonts_check_family_panose_proportion(ttFonts):
 )
 def com_google_fonts_check_family_panose_familytype(ttFonts):
   """Fonts have consistent PANOSE family type?"""
-  failed = False
+  passed = True
   familytype = None
   for ttfont in ttFonts:
     if familytype is None:
       familytype = ttfont['OS/2'].panose.bFamilyType
     if familytype != ttfont['OS/2'].panose.bFamilyType:
-      failed = True
+      passed = False
 
-  if failed:
-    yield FAIL, ("PANOSE family type is not"
-                 " the same accross this family."
-                 " In order to fix this,"
-                 " please make sure that the panose.bFamilyType value"
-                 " is the same in the OS/2 table of all of this family"
-                 " font files.")
+  if not passed:
+    yield FAIL,\
+          Message("inconsistency",
+                  "PANOSE family type is not the same across this family."
+                  " In order to fix this, please make sure that"
+                  " the panose.bFamilyType value is the same"
+                  " in the OS/2 table of all of this family font files.")
   else:
     yield PASS, "Fonts have consistent PANOSE family type."
 
@@ -69,8 +70,9 @@ def com_google_fonts_check_xavgcharwidth(ttFont):
   if ttFont['OS/2'].version >= 3:
     calculation_rule = "the average of the widths of all glyphs in the font"
     if not ttFont['hmtx'].metrics:  # May contain just '.notdef', which is valid.
-      yield FAIL, Message("missing-glyphs",
-                          "CRITICAL: Found no glyph width data in the hmtx table!")
+      yield FAIL,\
+            Message("missing-glyphs",
+                    "CRITICAL: Found no glyph width data in the hmtx table!")
       return
 
     width_sum = 0
@@ -118,9 +120,10 @@ def com_google_fonts_check_xavgcharwidth(ttFont):
     }
     glyph_order = ttFont.getGlyphOrder()
     if not all(character in glyph_order for character in weightFactors):
-      yield FAIL, Message("missing-glyphs",
-                          "Font is missing the required latin lowercase "
-                          "letters and/or space.")
+      yield FAIL,\
+            Message("missing-glyphs",
+                    "Font is missing the required"
+                    " latin lowercase letters and/or space.")
       return
 
     width_sum = 0
@@ -138,12 +141,12 @@ def com_google_fonts_check_xavgcharwidth(ttFont):
   elif difference < ACCEPTABLE_ERROR:
     yield INFO, (f"OS/2 xAvgCharWidth is {current_value} but it should be"
                  f" {expected_value} which corresponds to {calculation_rule}."
-                  " These are similar values, which"
-                  " may be a symptom of the slightly different"
-                  " calculation of the xAvgCharWidth value in"
-                  " font editors. There's further discussion on"
-                  " this at https://github.com/googlefonts/fontbakery"
-                  "/issues/1622")
+                 f" These are similar values, which"
+                 f" may be a symptom of the slightly different"
+                 f" calculation of the xAvgCharWidth value in"
+                 f" font editors. There's further discussion on"
+                 f" this at https://github.com/googlefonts/fontbakery"
+                 f"/issues/1622")
   else:
     yield WARN, (f"OS/2 xAvgCharWidth is {current_value} but it should be"
                  f" {expected_value} which corresponds to {calculation_rule}.")
@@ -151,8 +154,9 @@ def com_google_fonts_check_xavgcharwidth(ttFont):
 
 @check(
   id = 'com.adobe.fonts/check/fsselection_matches_macstyle',
-  rationale = """The bold and italic bits in OS/2.fsSelection must match the
-  bold and italic bits in head.macStyle per the OpenType spec."""
+  rationale = """
+    The bold and italic bits in OS/2.fsSelection must match the bold and italic bits in head.macStyle per the OpenType spec.
+  """
 )
 def com_adobe_fonts_check_fsselection_matches_macstyle(ttFont):
   """Check if OS/2 fsSelection matches head macStyle bold and italic bits."""
@@ -177,13 +181,14 @@ def com_adobe_fonts_check_fsselection_matches_macstyle(ttFont):
 
 @check(
   id = 'com.adobe.fonts/check/family/bold_italic_unique_for_nameid1',
-  rationale = """Per the OpenType spec: name ID 1 'is used in combination with
-  Font Subfamily name (name ID 2), and should be shared among at most four
-  fonts that differ only in weight or style ... This four-way distinction
-  should also be reflected in the OS/2.fsSelection field, using bits 0 and 5.' 
+  conditions=['RIBBI_ttFonts'],
+  rationale = """
+    Per the OpenType spec: name ID 1 'is used in combination with Font Subfamily name (name ID 2), and should be shared among at most four fonts that differ only in weight or style...
+
+    This four-way distinction should also be reflected in the OS/2.fsSelection field, using bits 0 and 5.
   """
 )
-def com_adobe_fonts_check_family_bold_italic_unique_for_nameid1(ttFonts):
+def com_adobe_fonts_check_family_bold_italic_unique_for_nameid1(RIBBI_ttFonts):
   """Check that OS/2.fsSelection bold & italic settings are unique
   for each NameID1"""
   from collections import Counter
@@ -192,7 +197,7 @@ def com_adobe_fonts_check_family_bold_italic_unique_for_nameid1(ttFonts):
 
   failed = False
   family_name_and_bold_italic = list()
-  for ttFont in ttFonts:
+  for ttFont in RIBBI_ttFonts:
     names_list = get_name_entry_strings(ttFont, NameID.FONT_FAMILY_NAME)
     # names_list will likely contain multiple entries, e.g. multiple copies
     # of the same name in the same language for different platforms, but
@@ -224,22 +229,13 @@ def com_adobe_fonts_check_family_bold_italic_unique_for_nameid1(ttFonts):
 @check(
   id = 'com.google.fonts/check/code_pages',
   rationale = """
-  At least some programs (such as Word and Sublime Text) under Windows 7
-  do not recognize fonts unless code page bits are properly set on the
-  ulCodePageRange1 (and/or ulCodePageRange2) fields of the OS/2 table.
+    At least some programs (such as Word and Sublime Text) under Windows 7 do not recognize fonts unless code page bits are properly set on the ulCodePageRange1 (and/or ulCodePageRange2) fields of the OS/2 table.
 
-  More specifically, the fonts are selectable in the font menu, but
-  whichever Windows API these applications use considers them unsuitable
-  for any character set, so anything set in these fonts is rendered
-  with a fallback font of Arial.
+    More specifically, the fonts are selectable in the font menu, but whichever Windows API these applications use considers them unsuitable for any character set, so anything set in these fonts is rendered with a fallback font of Arial.
 
-  This check currently does not identify which code pages should be set.
-  Auto-detecting coverage is not trivial since the OpenType specification
-  leaves the interpretation of whether a given code page is "functional"
-  or not open to the font developer to decide.
+    This check currently does not identify which code pages should be set. Auto-detecting coverage is not trivial since the OpenType specification leaves the interpretation of whether a given code page is "functional" or not open to the font developer to decide.
 
-  So here we simply detect as a FAIL when a given font has no code page
-  declared at all.
+    So here we simply detect as a FAIL when a given font has no code page declared at all.
   """
 )
 def com_google_fonts_check_code_pages(ttFont):
@@ -250,6 +246,6 @@ def com_google_fonts_check_code_pages(ttFont):
      (ttFont['OS/2'].ulCodePageRange1 == 0 and \
       ttFont['OS/2'].ulCodePageRange2 == 0):
     yield FAIL, ("No code pages defined in the OS/2 table"
-                 " ulCodePageRage1 and CodePageRage2 fields.")
+                 " ulCodePageRange1 and CodePageRange2 fields.")
   else:
     yield PASS, "At least one code page is defined."
