@@ -6,13 +6,12 @@ from fontbakery.fonts_profile import profile_factory # NOQA pylint: disable=unus
 @check(
   id = 'com.google.fonts/check/family/underline_thickness',
   rationale = """
-  Dave C Lemon (Adobe Type Team) recommends setting the underline
-  thickness to be consistent across the family.
+    Dave C Lemon (Adobe Type Team) recommends setting the underline thickness to be consistent across the family.
 
-  If thicknesses are not family consistent, words set on the same line which
-  have different styles look strange.
+    If thicknesses are not family consistent, words set on the same line which have different styles look strange.
 
-  See also: https://twitter.com/typenerd1/status/690361887926697986
+    See also:
+    https://twitter.com/typenerd1/status/690361887926697986
   """,
   misc_metadata = {
     'affects': [('InDesign', 'unspecified')]
@@ -35,7 +34,7 @@ def com_google_fonts_check_family_underline_thickness(ttFonts):
 
   if failed:
     msg = ("Thickness of the underline is not"
-           " the same accross this family. In order to fix this,"
+           " the same across this family. In order to fix this,"
            " please make sure that the underlineThickness value"
            " is the same in the 'post' table of all of this family"
            " font files.\n"
@@ -48,18 +47,35 @@ def com_google_fonts_check_family_underline_thickness(ttFonts):
 
 
 @check(
-  id = 'com.google.fonts/check/post_table_version'
+  id = 'com.google.fonts/check/post_table_version',
+  rationale = """
+    Apple recommends against using 'post' table format 3 under most circumstances, as it can create problems with some printer drivers and PDF documents. The savings in disk space usually does not justify the potential loss in functionality.
+    Source: https://developer.apple.com/fonts/TrueType-Reference-Manual/RM06/Chap6post.html
+
+    The CFF2 table does not contain glyph names, so variable OTFs should be allowed to use post table version 2.
+
+    This check expects:
+    - Version 2 for TTF or OTF CFF2 Variable fonts
+    - Version 3 for OTF
+  """,
+  misc_metadata = {
+    'request': [
+      'https://github.com/google/fonts/issues/215',
+      'https://github.com/googlefonts/fontbakery/issues/2638'
+    ]
+  }
 )
 def com_google_fonts_check_post_table_version(ttFont, is_ttf):
-  """Font has correct post table version (2 for TTF, 3 for OTF)?"""
+  """Font has correct post table version?"""
   formatType = ttFont['post'].formatType
-  if is_ttf:
+  is_var = "fvar" in ttFont.keys()
+  is_cff2 = "CFF2" in ttFont.keys()
+  if is_ttf or (is_var and is_cff2):
     expected = 2
   else:
     expected = 3
   if formatType != expected:
-    yield FAIL, ("Post table should be version {} instead of {}."
-                 " More info at https://github.com/google/fonts/"
-                 "issues/215").format(expected, formatType)
+    yield FAIL, (f"Post table should be version {expected}"
+                 f" instead of {formatType}.")
   else:
     yield PASS, f"Font has post table version {expected}."
