@@ -7,20 +7,25 @@ from fontbakery.message import Message
 from fontbakery.fonts_profile import profile_factory
 from fontbakery.profiles.opentype import OPENTYPE_PROFILE_CHECKS
 
-profile_imports = ('fontbakery.profiles.opentype',)
+profile_imports = ('fontbakery.profiles.opentype',
+                   '.shared_conditions')
 profile = profile_factory(default_section=Section("Universal"))
 
 THIRDPARTY_CHECKS = [
   'com.google.fonts/check/ots',
   'com.google.fonts/check/ftxvalidator',
-  'com.google.fonts/check/fontforge',
-  'com.google.fonts/check/fontforge_stderr',
   'com.google.fonts/check/ftxvalidator_is_available'
 ]
 
+SUPERFAMILY_CHECKS = [
+  'com.google.fonts/check/superfamily/list',
+  'com.google.fonts/check/superfamily/vertical_metrics',
+]
+
 UNIVERSAL_PROFILE_CHECKS = \
   OPENTYPE_PROFILE_CHECKS + \
-  THIRDPARTY_CHECKS + [
+  THIRDPARTY_CHECKS + \
+  SUPERFAMILY_CHECKS + [
   'com.google.fonts/check/name/trailing_spaces',
   'com.google.fonts/check/family/win_ascent_and_descent',
   'com.google.fonts/check/os2_metrics_match_hhea',
@@ -40,7 +45,7 @@ UNIVERSAL_PROFILE_CHECKS = \
 ]
 
 @check(
-  id='com.google.fonts/check/name/trailing_spaces',
+  id = 'com.google.fonts/check/name/trailing_spaces',
 )
 def com_google_fonts_check_name_trailing_spaces(ttFont):
   """Name table records must not have trailing spaces."""
@@ -63,27 +68,17 @@ def com_google_fonts_check_name_trailing_spaces(ttFont):
 
 @check(
   id = 'com.google.fonts/check/family/win_ascent_and_descent',
-  conditions = ['vmetrics']
+  conditions = ['vmetrics'],
+  rationale = """
+    A font's winAscent and winDescent values should be greater than the head table's yMax, abs(yMin) values. If they are less than these values, clipping can occur on Windows platforms (https://github.com/RedHatBrand/Overpass/issues/33).
+
+    If the font includes tall/deep writing systems such as Arabic or Devanagari, the winAscent and winDescent can be greater than the yMax and abs(yMin) to accommodate vowel marks.
+
+    When the win Metrics are significantly greater than the upm, the linespacing can appear too loose. To counteract this, enabling the OS/2 fsSelection bit 7 (Use_Typo_Metrics), will force Windows to use the OS/2 typo values instead. This means the font developer can control the linespacing with the typo values, whilst avoiding clipping by setting the win values to values greater than the yMax and abs(yMin).
+  """
 )
 def com_google_fonts_check_family_win_ascent_and_descent(ttFont, vmetrics):
-  """Checking OS/2 usWinAscent & usWinDescent.
-
-  A font's winAscent and winDescent values should be greater than the
-  head table's yMax, abs(yMin) values. If they are less than these
-  values, clipping can occur on Windows platforms,
-  https://github.com/RedHatBrand/Overpass/issues/33
-
-  If the font includes tall/deep writing systems such as Arabic or
-  Devanagari, the winAscent and winDescent can be greater than the yMax and
-  abs(yMin) to accommodate vowel marks.
-
-  When the win Metrics are significantly greater than the upm, the
-  linespacing can appear too loose. To counteract this, enabling the
-  OS/2 fsSelection bit 7 (Use_Typo_Metrics), will force Windows to use the
-  OS/2 typo values instead. This means the font developer can control the
-  linespacing with the typo values, whilst avoiding clipping by setting
-  the win values to values greater than the yMax and abs(yMin).
-  """
+  """Checking OS/2 usWinAscent & usWinDescent."""
   failed = False
 
   # OS/2 usWinAscent:
@@ -123,18 +118,13 @@ def com_google_fonts_check_family_win_ascent_and_descent(ttFont, vmetrics):
 
 @check(
   id = 'com.google.fonts/check/os2_metrics_match_hhea',
-  rationale = """When OS/2 and hhea vertical metrics match, the same
-  linespacing results on macOS, GNU+Linux and Windows. Unfortunately as of 2018,
-  Google Fonts has released many fonts with vertical metrics that don't match
-  in this way. When we fix this issue in these existing families, we will
-  create a visible change in line/paragraph layout for either Windows or macOS
-  users, which will upset some of them.
+  rationale = """
+    When OS/2 and hhea vertical metrics match, the same linespacing results on macOS, GNU+Linux and Windows. Unfortunately as of 2018, Google Fonts has released many fonts with vertical metrics that don't match in this way. When we fix this issue in these existing families, we will create a visible change in line/paragraph layout for either Windows or macOS users, which will upset some of them.
 
-  But we have a duty to fix broken stuff, and inconsistent paragraph layout is
-  unacceptably broken when it is possible to avoid it.
+    But we have a duty to fix broken stuff, and inconsistent paragraph layout is unacceptably broken when it is possible to avoid it.
 
-  If users complain and prefer the old broken version, they are libre to take
-  care of their own situation."""
+    If users complain and prefer the old broken version, they have the freedom to take care of their own situation.
+  """
 )
 def com_google_fonts_check_os2_metrics_match_hhea(ttFont):
   """Checking OS/2 Metrics match hhea Metrics.
@@ -147,59 +137,33 @@ def com_google_fonts_check_os2_metrics_match_hhea(ttFont):
   """
   # OS/2 sTypoAscender and sTypoDescender match hhea ascent and descent
   if ttFont["OS/2"].sTypoAscender != ttFont["hhea"].ascent:
-    yield FAIL, Message("ascender",
-                        "OS/2 sTypoAscender and hhea ascent must be equal.")
+    yield FAIL,\
+          Message("ascender",
+                  f"OS/2 sTypoAscender ({ttFont['OS/2'].sTypoAscender})"
+                  f" and hhea ascent ({ttFont['hhea'].ascent})"
+                  f" must be equal.")
   elif ttFont["OS/2"].sTypoDescender != ttFont["hhea"].descent:
-    yield FAIL, Message("descender",
-                        "OS/2 sTypoDescender and hhea descent must be equal.")
+    yield FAIL,\
+          Message("descender",
+                  f"OS/2 sTypoDescender ({ttFont['OS/2'].sTypoDescender})"
+                  f" and hhea descent ({ttFont['hhea'].descent})"
+                  f" must be equal.")
   else:
     yield PASS, ("OS/2.sTypoAscender/Descender values"
                  " match hhea.ascent/descent.")
 
 
-@condition
-def fontforge_check_results(font):
-  # Would be AdobeBlank.ttf usually
-  if "adobeblank" in font.lower():
-    return {"skip": "Skipping AdobeBlank since "
-                    "this font is a very peculiar hack."}
-
-  import subprocess
-  cmd = (
-        'import fontforge, sys;'
-        'status = fontforge.open("{}").validate();'
-        'sys.stdout.write(status.__str__());'.format
-        )
-
-  p = subprocess.Popen(['python', '-c', cmd(font)],
-                       stderr=subprocess.PIPE,
-                       stdout=subprocess.PIPE
-                      )
-  ret_val, ff_err_messages = p.communicate()
-  try:
-    return {
-      "validation_state": int(ret_val),
-      "ff_err_messages": ff_err_messages.decode("utf-8")
-    }
-  except:
-    return None
-
-
 @check(
   id = 'com.google.fonts/check/family/single_directory',
+  rationale = """
+    If the set of font files passed in the command line is not all in the same directory, then we warn the user since the tool will interpret the set of files as belonging to a single family (and it is unlikely that the user would store the files from a single family spreaded in several separate directories).
+  """,
   misc_metadata = {
     'priority': PriorityLevel.CRITICAL
   }
 )
 def com_google_fonts_check_family_single_directory(fonts):
-  """Checking all files are in the same directory.
-
-  If the set of font files passed in the command line is not all in the
-  same directory, then we warn the user since the tool will interpret
-  the set of files as belonging to a single family (and it is unlikely
-  that the user would store the files from a single family spreaded in
-  several separate directories).
-  """
+  """Checking all files are in the same directory."""
 
   directories = []
   for target_file in fonts:
@@ -219,49 +183,45 @@ def com_google_fonts_check_family_single_directory(fonts):
 
 
 @condition
-def ftxvalidator_is_available():
+def ftxvalidator_cmd():
   """ Test if `ftxvalidator` is a command; i.e. an executable with a path."""
   import shutil
-  return shutil.which('ftxvalidator') is not None
+  return shutil.which('ftxvalidator')
 
 
 @check(
   id = 'com.google.fonts/check/ftxvalidator_is_available',
   rationale = """
-    There's no reasonable (and legal) way to run the command `ftxvalidator`
-    of the Apple Font Tool Suite on a non-macOS machine. I.e. on GNU+Linux
-    or Windows etc.
+    There's no reasonable (and legal) way to run the command `ftxvalidator` of the Apple Font Tool Suite on a non-macOS machine. I.e. on GNU+Linux or Windows etc.
 
-    If Font Bakery is not running on an OSX machine, the machine running
-    Font Bakery could access `ftxvalidator` on OSX, e.g. via ssh or a
-    remote procedure call (rpc).
+    If Font Bakery is not running on an OSX machine, the machine running Font Bakery could access `ftxvalidator` on OSX, e.g. via ssh or a remote procedure call (rpc).
 
     There's an ssh example implementation at:
     https://github.com/googlefonts/fontbakery/blob/master/prebuilt/workarounds/ftxvalidator/ssh-implementation/ftxvalidator
-
-    This check was suggested and requested at:
-    https://github.com/googlefonts/fontbakery/issues/2184
-  """
+  """,
+  misc_metadata = {
+    'request': 'https://github.com/googlefonts/fontbakery/issues/2184'
+  }
 )
-def com_google_fonts_check_ftxvalidator_is_available(ftxvalidator_is_available):
+def com_google_fonts_check_ftxvalidator_is_available(ftxvalidator_cmd):
   """Is the command `ftxvalidator` (Apple Font Tool Suite) available?"""
-  if ftxvalidator_is_available:
-    return PASS, "ftxvalidator is available."
+  if ftxvalidator_cmd:
+    yield PASS, f"ftxvalidator is available at {ftxvalidator_cmd}"
   else:
-    return WARN, "ftxvalidator is not available."
+    yield WARN, "Could not find ftxvalidator."
 
 
 @check(
   id = 'com.google.fonts/check/ftxvalidator',
-  conditions = ['ftxvalidator_is_available']
+  conditions = ['ftxvalidator_cmd']
 )
-def com_google_fonts_check_ftxvalidator(font):
+def com_google_fonts_check_ftxvalidator(font, ftxvalidator_cmd):
   """Checking with ftxvalidator."""
   import plistlib
   try:
     import subprocess
     ftx_cmd = [
-        "ftxvalidator",
+        ftxvalidator_cmd,
         "-t",
         "all",  # execute all checks
         font
@@ -275,7 +235,7 @@ def com_google_fonts_check_ftxvalidator(font):
       yield PASS, "ftxvalidator passed this file"
     else:
       ftx_cmd = [
-          "ftxvalidator",
+          ftxvalidator_cmd,
           "-T",  # Human-readable output
           "-r",  # Generate a full report
           "-t",
@@ -288,8 +248,6 @@ def com_google_fonts_check_ftxvalidator(font):
   except subprocess.CalledProcessError as e:
     yield ERROR, ("ftxvalidator returned an error code. Output follows:"
                  "\n\n{}\n").format(e.output.decode('utf-8'))
-  except OSError:
-    yield ERROR, "ftxvalidator is not available!"
 
 
 @check(
@@ -321,7 +279,7 @@ def is_up_to_date(installed, latest):
   has_githash = ".dev" in installed
   installed = installed.split(".dev")[0]
 
-  # Maybe the installed version is even newer than the 
+  # Maybe the installed version is even newer than the
   # released one (such as during development on git).
   # That's what we're trying to detect here:
   installed = installed.split('.')
@@ -365,6 +323,10 @@ def com_google_fonts_check_fontbakery_version():
                    f" while a newer {latest_str} is already available."
                     " Please upgrade it with 'pip install -U fontbakery'")
     yield INFO, pip_output.decode()
+  except Exception:
+    yield FAIL, ("Unable to detect what's the latest version of"
+                 " FontBakery available. Maybe we're offline?"
+                 " Please check Internet access and try again.")
   except subprocess.CalledProcessError as e:
     yield ERROR, ("Running 'pip search fontbakery' returned an error code."
                   " Output follows :\n\n{}\n").format(e.output.decode())
@@ -374,199 +336,17 @@ def com_google_fonts_check_fontbakery_version():
 
 
 @check(
-  id = 'com.google.fonts/check/fontforge_stderr',
-  conditions = ['fontforge_check_results']
-)
-def com_google_fonts_check_fontforge_stderr(font, fontforge_check_results):
-  """FontForge validation outputs error messages?"""
-  if "skip" in fontforge_check_results:
-    yield SKIP, fontforge_check_results["skip"]
-    return
+  id = 'com.google.fonts/check/mandatory_glyphs',
+  rationale = """
+    The OpenType specification v1.8.2 recommends that the first glyph is the .notdef glyph without a codepoint assigned and with a drawing.
 
-  filtered_err_msgs = ""
-  for line in fontforge_check_results["ff_err_messages"].split('\n'):
-    if ('The following table(s) in the font'
-        ' have been ignored by FontForge') in line:
-      continue
-    if "Ignoring 'DSIG' digital signature table" in line:
-      continue
-    filtered_err_msgs += line + '\n'
+    https://docs.microsoft.com/en-us/typography/opentype/spec/recom#glyph-0-the-notdef-glyph
 
-  if len(filtered_err_msgs.strip()) > 0:
-    yield WARN, ("FontForge seems to dislike certain aspects of this font file."
-                 " The actual meaning of the log messages below is not always"
-                 " clear and may require further investigation.\n\n"
-                 "{}").format(filtered_err_msgs)
-  else:
-    yield PASS, "FontForge validation did not output any error message."
-
-
-@condition
-def fontforge_skip_checks():
-  """ return a bitmask of the checks to skip
-
-  E.g. to skip:
-    0x2: Contours are closed?
-    0x40: Glyph names referred to from glyphs present in the font
-    0x200: Font doesn't have invalid glyph names
-  do:
-    return 0x2 + 0x40 + 0x200
-
-  override with @condition(force=True) to customize this
+    Pre-v1.8, it was recommended that a font should also contain a .null, CR and space glyph. This might have been relevant for applications on MacOS 9.
   """
-  return None
-
-@check(
-  id = 'com.google.fonts/check/fontforge',
-  conditions = ['fontforge_check_results']
-)
-def com_google_fonts_check_fontforge(fontforge_check_results, fontforge_skip_checks):
-  """FontForge checks."""
-  if "skip" in fontforge_check_results:
-    yield SKIP, fontforge_check_results["skip"]
-    return
-
-  validation_state = fontforge_check_results["validation_state"]
-  fontforge_checks = (
-      ("Contours are closed?",
-       0x2, FAIL,
-       "Contours are not closed!", "Contours are closed.")
-
-    , ("Contours do not intersect",
-       0x4, WARN,
-       "There are countour intersections!",
-       "Contours do not intersect.")
-
-    , ("Contours have correct directions",
-       0x8, WARN,
-       "Contours have incorrect directions!",
-       "Contours have correct directions.")
-
-    , ("References in the glyph haven't been flipped",
-       0x10, FAIL,
-       "References in the glyph have been flipped!",
-       "References in the glyph haven't been flipped.")
-
-    , ("Glyphs have points at extremas",
-       0x20, WARN,
-       "Glyphs do not have points at extremas!",
-       "Glyphs have points at extremas.")
-
-    , ("Glyph names referred to from glyphs present in the font",
-       0x40, FAIL,
-       "Glyph names referred to from glyphs"
-       " not present in the font!",
-       "Glyph names referred to from glyphs"
-       " present in the font.")
-
-    , ("Points (or control points) are not too far apart",
-       0x40000, FAIL,
-       "Points (or control points) are too far apart!",
-       "Points (or control points) are not too far apart.")
-
-    , ("Not more than 1,500 points in any glyph"
-       " (a PostScript limit)",
-       0x80, FAIL,
-       "There are glyphs with more than 1,500 points!"
-       "Exceeds a PostScript limit.",
-       "Not more than 1,500 points in any glyph"
-       " (a PostScript limit).")
-
-    , ("PostScript has a limit of 96 hints in glyphs",
-       0x100, FAIL,
-       "Exceeds PostScript limit of 96 hints per glyph",
-       "Font respects PostScript limit of 96 hints per glyph")
-
-    , ("Font doesn't have invalid glyph names",
-       0x200, FAIL,
-       "Font has invalid glyph names!",
-       "Font doesn't have invalid glyph names.")
-
-    , ("Glyphs have allowed numbers of points defined in maxp",
-       0x400, FAIL,
-       "Glyphs exceed allowed numbers of points defined in maxp",
-       "Glyphs have allowed numbers of points defined in maxp.")
-
-    , ("Glyphs have allowed numbers of paths defined in maxp",
-       0x800, FAIL,
-       "Glyphs exceed allowed numbers of paths defined in maxp!",
-       "Glyphs have allowed numbers of paths defined in maxp.")
-
-    , ("Composite glyphs have allowed numbers"
-       " of points defined in maxp?",
-       0x1000, FAIL,
-       "Composite glyphs exceed allowed numbers"
-       " of points defined in maxp!",
-       "Composite glyphs have allowed numbers"
-       " of points defined in maxp.")
-
-    , ("Composite glyphs have allowed numbers"
-       " of paths defined in maxp",
-       0x2000, FAIL,
-       "Composite glyphs exceed"
-       " allowed numbers of paths defined in maxp!",
-       "Composite glyphs have"
-       " allowed numbers of paths defined in maxp.")
-
-    , ("Glyphs instructions have valid lengths",
-       0x4000, FAIL,
-       "Glyphs instructions have invalid lengths!",
-       "Glyphs instructions have valid lengths.")
-
-    , ("Points in glyphs are integer aligned",
-       0x80000, FAIL,
-       "Points in glyphs are not integer aligned!",
-       "Points in glyphs are integer aligned.")
-
-    # According to the opentype spec, if a glyph contains an anchor point
-    # for one anchor class in a subtable, it must contain anchor points
-    # for all anchor classes in the subtable. Even it, logically,
-    # they do not apply and are unnecessary.
-    , ("Glyphs have all required anchors.",
-       0x100000, FAIL,
-       "Glyphs do not have all required anchors!",
-       "Glyphs have all required anchors.")
-
-    , ("Glyph names are unique?",
-       0x200000, FAIL,
-       "Glyph names are not unique!",
-       "Glyph names are unique.")
-
-    , ("Unicode code points are unique?",
-       0x400000, FAIL,
-       "Unicode code points are not unique!",
-       "Unicode code points are unique.")
-
-    , ("Do hints overlap?",
-       0x800000, FAIL,
-       "Hints should NOT overlap!",
-       "Hints do not overlap.")
-  )
-
-  for description, bit, failure_status_override, fail_msg, ok_msg in fontforge_checks:
-    if fontforge_skip_checks is not None and \
-       bool(fontforge_skip_checks & bit) is not False:
-      yield SKIP, description
-    elif bool(validation_state & bit) is not False:
-      yield failure_status_override, f"fontforge-check: {fail_msg}"
-    else:
-      yield PASS, f"fontforge-check: {ok_msg}"
-
-
-@check(
-  id = 'com.google.fonts/check/mandatory_glyphs'
 )
 def com_google_fonts_check_mandatory_glyphs(ttFont):
-  """Font contains .notdef as first glyph?
-
-  The OpenType specification v1.8.2 recommends that the first glyph is the
-  .notdef glyph without a codepoint assigned and with a drawing.
-
-  https://docs.microsoft.com/en-us/typography/opentype/spec/recom#glyph-0-the-notdef-glyph
-
-  Pre-v1.8, it was recommended that a font should also contain a .null, CR and
-  space glyph. This might have been relevant for applications on MacOS 9.
-  """
+  """Font contains .notdef as first glyph?"""
   from fontbakery.utils import glyph_has_ink
 
   if (
@@ -592,9 +372,10 @@ def com_google_fonts_check_mandatory_glyphs(ttFont):
 def com_google_fonts_check_whitespace_glyphs(ttFont, missing_whitespace_chars):
   """Font contains glyphs for whitespace characters?"""
   if missing_whitespace_chars != []:
-    yield FAIL, ("Whitespace glyphs missing for"
-                 " the following codepoints:"
-                 " {}.").format(", ".join(missing_whitespace_chars))
+    yield FAIL, Message("missing-whitespace-glyphs",
+                    ("Whitespace glyphs missing for"
+                     " the following codepoints:"
+                     " {}.").format(", ".join(missing_whitespace_chars)))
   else:
     yield PASS, "Font contains glyphs for whitespace characters."
 
@@ -655,10 +436,10 @@ def com_google_fonts_check_whitespace_ink(ttFont):
 
   # code-points for all "whitespace" chars:
   WHITESPACE_CHARACTERS = [
-      0x0009, 0x000A, 0x000B, 0x000C, 0x000D, 0x0020, 0x0085, 0x00A0, 0x1680,
-      0x2000, 0x2001, 0x2002, 0x2003, 0x2004, 0x2005, 0x2006, 0x2007, 0x2008,
-      0x2009, 0x200A, 0x2028, 0x2029, 0x202F, 0x205F, 0x3000, 0x180E, 0x200B,
-      0x2060, 0xFEFF
+    0x0009, 0x000A, 0x000B, 0x000C, 0x000D, 0x0020, 0x0085, 0x00A0, 0x1680,
+    0x2000, 0x2001, 0x2002, 0x2003, 0x2004, 0x2005, 0x2006, 0x2007, 0x2008,
+    0x2009, 0x200A, 0x2028, 0x2029, 0x202F, 0x205F, 0x3000, 0x180E, 0x200B,
+    0x2060, 0xFEFF
   ]
   failed = False
   for codepoint in WHITESPACE_CHARACTERS:
@@ -674,17 +455,13 @@ def com_google_fonts_check_whitespace_ink(ttFont):
 
 @check(
   id='com.google.fonts/check/required_tables',
-  conditions=['is_ttf'],
-  rationale="""Depending on the typeface and coverage of a font, certain
-  tables are recommended for optimum quality. For example, the performance
-  of a non-linear font is improved if the VDMX, LTSH, and hdmx tables are
-  present. Non-monospaced Latin fonts should have a kern table. A gasp table
-  is necessary if a designer wants to influence the sizes at which grayscaling
-  is used under Windows. A DSIG table containing a digital signature helps
-  ensure the integrity of the font file. Etc.
+  conditions = ['is_ttf'],
+  rationale = """
+    Depending on the typeface and coverage of a font, certain tables are recommended for optimum quality. For example, the performance of a non-linear font is improved if the VDMX, LTSH, and hdmx tables are present. Non-monospaced Latin fonts should have a kern table. A gasp table is necessary if a designer wants to influence the sizes at which grayscaling is used under Windows. A DSIG table containing a digital signature helps ensure the integrity of the font file. Etc.
   """
-  # FIXME: The rationale description above comes from FontValidator, check W0022.
-  #        We may want to improve it and/or rephrase it.
+  # FIXME:
+  # The rationale description above comes from FontValidator, check W0022.
+  # We may want to improve it and/or rephrase it.
 )
 def com_google_fonts_check_required_tables(ttFont):
   """Font contains all required tables?"""
@@ -730,52 +507,66 @@ def com_google_fonts_check_required_tables(ttFont):
 
 @check(
   id = 'com.google.fonts/check/unwanted_tables',
-  rationale = """Some font editors store source data in their own SFNT
-  tables, and these can sometimes sneak into final release files,
-  which should only have OpenType spec tables."""
+  rationale = """
+    Some font editors store source data in their own SFNT tables, and these can sometimes sneak into final release files, which should only have OpenType spec tables.
+  """
 )
 def com_google_fonts_check_unwanted_tables(ttFont):
   """Are there unwanted tables?"""
   UNWANTED_TABLES = {
-      'FFTM': '(from FontForge)',
-      'TTFA': '(from TTFAutohint)',
-      'TSI0': '(from VTT)',
-      'TSI1': '(from VTT)',
-      'TSI2': '(from VTT)',
-      'TSI3': '(from VTT)',
-      'TSI5': '(from VTT)',
-      'prop': '' # FIXME: why is this one unwanted?
+    'FFTM': 'Table contains redundant FontForge timestamp info',
+    'TTFA': 'Redundant TTFAutohint table',
+    'TSI0': 'Table contains data only used in VTT',
+    'TSI1': 'Table contains data only used in VTT',
+    'TSI2': 'Table contains data only used in VTT',
+    'TSI3': 'Table contains data only used in VTT',
+    'TSI5': 'Table contains data only used in VTT',
+    'prop': '', # FIXME: why is this one unwanted?
+      # Marc Foley found that VFs containing a MVAR table have very
+      # loose vertical metrics, even if the MVAR table hasn't adjusted
+      # any vertical metric values.
+    'MVAR': ('Produces a bug in DirectWrite which causes'
+             ' https://bugzilla.mozilla.org/show_bug.cgi?id=1492477,'
+             ' https://github.com/google/fonts/issues/2085')
   }
   unwanted_tables_found = []
   for table in ttFont.keys():
     if table in UNWANTED_TABLES.keys():
       info = UNWANTED_TABLES[table]
-      unwanted_tables_found.append(f"{table} {info}")
+      unwanted_tables_found.append(f'Table: {table}\nReason: {info}\n')
 
   if len(unwanted_tables_found) > 0:
-    yield FAIL, ("Unwanted tables were found"
-                 " in the font and should be removed, either by"
-                 " fonttools/ttx or by editing them using the tool"
-                 " they are from:"
-                 " {}").format(", ".join(unwanted_tables_found))
+    yield FAIL, ("The following unwanted font tables were found:\n"
+                 "{}\n"
+                 "They can be removed with the gftools fix-unwanted-tables script."
+                 ).format("\n".join(unwanted_tables_found))
   else:
     yield PASS, "There are no unwanted tables."
 
 
 @check(
   id = 'com.google.fonts/check/valid_glyphnames',
-  rationale = """Microsoft's recommendations for OpenType Fonts states the
-  following, 'NOTE: The PostScript glyph name must be no longer than 31
-  characters, include only uppercase or lowercase English letters, European
-  digits, the period or the underscore, i.e. from the set [A-Za-z0-9_.] and
-  should start with a letter, except the special glyph name ".notdef" which
-  starts with a period.'
+  rationale = """
+    Microsoft's recommendations for OpenType Fonts states the following:
+    
+    'NOTE: The PostScript glyph name must be no longer than 31 characters, include only uppercase or lowercase English letters, European digits, the period or the underscore, i.e. from the set [A-Za-z0-9_.] and should start with a letter, except the special glyph name ".notdef" which starts with a period.'
 
-  https://docs.microsoft.com/en-us/typography/opentype/spec/recom#post-table
-  """
+    https://docs.microsoft.com/en-us/typography/opentype/spec/recom#post-table
+
+
+    In practice, though, particularly in modern environments, glyph names can be as long as 63 characters.
+    According to the "Adobe Glyph List Specification" available at:
+
+    https://github.com/adobe-type-tools/agl-specification
+  """,
+  misc_metadata = {
+    'requested': "https://github.com/googlefonts/fontbakery/issues/2832" # increase limit to 63 chars
+  }
 )
 def com_google_fonts_check_valid_glyphnames(ttFont):
   """Glyph names are all valid?"""
+  from fontbakery.utils import pretty_print_list
+
   if ttFont.sfntVersion == b'\x00\x01\x00\x00' and ttFont.get(
       "post") and ttFont["post"].formatType == 3.0:
     yield SKIP, ("TrueType fonts with a format 3.0 post table contain no"
@@ -783,31 +574,37 @@ def com_google_fonts_check_valid_glyphnames(ttFont):
   else:
     import re
     bad_names = []
+    warn_names = []
     for _, glyphName in enumerate(ttFont.getGlyphOrder()):
       if glyphName in [".null", ".notdef", ".ttfautohint"]:
         # These 2 names are explicit exceptions
         # in the glyph naming rules
         continue
-      if not re.match(r'^(?![.0-9])[a-zA-Z._0-9]{1,31}$', glyphName):
+      if not re.match(r'^(?![.0-9])[a-zA-Z._0-9]{1,63}$', glyphName):
         bad_names.append(glyphName)
+      if len(glyphName) > 31 and len(glyphName) <= 63:
+        warn_names.append(glyphName)
 
     if len(bad_names) == 0:
-      yield PASS, "Glyph names are all valid."
+      if len(warn_names) == 0:
+        yield PASS, "Glyph names are all valid."
+      else:
+        yield WARN,\
+              Message('legacy-long-names',
+                      ("The following glyph names may be too"
+                       " long for some legacy systems which may"
+                       " expect a maximum 31-char length limit:\n"
+                       "{}").format(pretty_print_list(warn_names)))
     else:
-      from fontbakery.utils import pretty_print_list
-      yield FAIL, ("The following glyph names do not comply"
-                   " with naming conventions: {}\n\n"
-                   " A glyph name may be up to 31 characters in length,"
-                   " must be entirely comprised of characters from"
-                   " the following set:"
-                   " A-Z a-z 0-9 .(period) _(underscore). and must not"
-                   " start with a digit or period."
-                   " There are a few exceptions"
-                   " such as the special character \".notdef\"."
-                   " The glyph names \"twocents\", \"a1\", and \"_\""
-                   " are all valid, while \"2cents\""
-                   " and \".twocents\" are not."
-                   "").format(pretty_print_list(bad_names))
+      yield FAIL,\
+            Message('found-invalid-names',
+                    ("The following glyph names do not comply"
+                     " with naming conventions: {}\n\n"
+                     " such as the special character \".notdef\"."
+                     " The glyph names \"twocents\", \"a1\", and \"_\""
+                     " are all valid, while \"2cents\""
+                     " and \".twocents\" are not."
+                     "").format(pretty_print_list(bad_names)))
 
 
 @check(
@@ -815,7 +612,7 @@ def com_google_fonts_check_valid_glyphnames(ttFont):
   rationale = """
     Duplicate glyph names prevent font installation on Mac OS X.
   """,
-  misc_metadata={
+  misc_metadata = {
     'affects': [('Mac', 'unspecified')]
   }
 )
@@ -948,13 +745,15 @@ def com_google_fonts_check_ttx_roundtrip(font):
 
 @check(
   id = 'com.google.fonts/check/family/vertical_metrics',
-  rationale="""
-  We want all fonts within a family to have the same vertical metrics so
-  their line spacing is consistent across the family.
-  """
+  rationale = """
+    We want all fonts within a family to have the same vertical metrics so their line spacing is consistent across the family.
+  """,
+  misc_metadata = {
+    'request': 'https://github.com/googlefonts/fontbakery/issues/1487'
+  }
 )
 def com_google_fonts_check_family_vertical_metrics(ttFonts):
-  """Each font in a family must have the same vertical metrics values."""
+  """Each font in a family must have the same set of vertical metrics values."""
   failed = []
   vmetrics = {
     "sTypoAscender": {},
@@ -966,28 +765,98 @@ def com_google_fonts_check_family_vertical_metrics(ttFonts):
     "descent": {}
   }
 
-  for ttfont in ttFonts:
-      full_font_name = ttfont['name'].getName(4, 3, 1, 1033).toUnicode()
-      vmetrics['sTypoAscender'][full_font_name] = ttfont['OS/2'].sTypoAscender
-      vmetrics['sTypoDescender'][full_font_name] = ttfont['OS/2'].sTypoDescender
-      vmetrics['sTypoLineGap'][full_font_name] = ttfont['OS/2'].sTypoLineGap
-      vmetrics['usWinAscent'][full_font_name] = ttfont['OS/2'].usWinAscent
-      vmetrics['usWinDescent'][full_font_name] = ttfont['OS/2'].usWinDescent
-      vmetrics['ascent'][full_font_name] = ttfont['hhea'].ascent
-      vmetrics['descent'][full_font_name] = ttfont['hhea'].descent
+  for ttFont in ttFonts:
+    full_font_name = ttFont['name'].getName(4, 3, 1, 1033).toUnicode()
+    vmetrics['sTypoAscender'][full_font_name] = ttFont['OS/2'].sTypoAscender
+    vmetrics['sTypoDescender'][full_font_name] = ttFont['OS/2'].sTypoDescender
+    vmetrics['sTypoLineGap'][full_font_name] = ttFont['OS/2'].sTypoLineGap
+    vmetrics['usWinAscent'][full_font_name] = ttFont['OS/2'].usWinAscent
+    vmetrics['usWinDescent'][full_font_name] = ttFont['OS/2'].usWinDescent
+    vmetrics['ascent'][full_font_name] = ttFont['hhea'].ascent
+    vmetrics['descent'][full_font_name] = ttFont['hhea'].descent
 
   for k, v in vmetrics.items():
-      metric_vals = set(vmetrics[k].values())
-      if len(metric_vals) != 1:
-          failed.append(k)
+    metric_vals = set(vmetrics[k].values())
+    if len(metric_vals) != 1:
+      failed.append(k)
 
   if failed:
-      for k in failed:
-        s = ["{}: {}".format(k, v) for k, v in vmetrics[k].items()]
-        yield FAIL, ("{} is not the same across the family:\n:"
-                     "{}".format(k, "\n".join(s)))
+    for k in failed:
+      s = ["{}: {}".format(k, v) for k, v in vmetrics[k].items()]
+      s = "\n".join(s)
+      yield FAIL, (f"{k} is not the same across the family:\n"
+                   f"{s}")
   else:
-      yield PASS, "Vertical metrics are the same across the family"
+    yield PASS, f"Vertical metrics are the same across the family."
+
+
+@check(
+  id = 'com.google.fonts/check/superfamily/list',
+  rationale = """
+    This is a merely informative check that lists all sibling families detected by fontbakery.
+
+    Only the fontfiles in these directories will be considered in superfamily-level checks.
+  """
+)
+def com_google_fonts_check_superfamily_list(superfamily):
+  """List all superfamily filepaths"""
+  for family in superfamily:
+    yield INFO,\
+          Message("family-path", os.path.split(family[0])[0])
+
+
+@check(
+  id = 'com.google.fonts/check/superfamily/vertical_metrics',
+  rationale = """
+    We may want all fonts within a super-family (all sibling families) to have the same vertical metrics so their line spacing is consistent across the super-family.
+
+    This is an experimental extended version of com.google.fonts/check/superfamily/vertical_metrics and for now it will only result in WARNs.
+  """,
+  misc_metadata = {
+    'request': 'https://github.com/googlefonts/fontbakery/issues/1487'
+  }
+)
+def com_google_fonts_check_superfamily_vertical_metrics(superfamily_ttFonts):
+  """Each font in set of sibling families must have the same set of vertical metrics values."""
+  if len(superfamily_ttFonts) < 2:
+    yield SKIP, "Sibling families were not detected."
+    return
+
+  warn = []
+  vmetrics = {
+    "sTypoAscender": {},
+    "sTypoDescender": {},
+    "sTypoLineGap": {},
+    "usWinAscent": {},
+    "usWinDescent": {},
+    "ascent": {},
+    "descent": {}
+  }
+
+  for family_ttFonts in superfamily_ttFonts:
+    for ttFont in family_ttFonts:
+      full_font_name = ttFont['name'].getName(4, 3, 1, 1033).toUnicode()
+      vmetrics['sTypoAscender'][full_font_name] = ttFont['OS/2'].sTypoAscender
+      vmetrics['sTypoDescender'][full_font_name] = ttFont['OS/2'].sTypoDescender
+      vmetrics['sTypoLineGap'][full_font_name] = ttFont['OS/2'].sTypoLineGap
+      vmetrics['usWinAscent'][full_font_name] = ttFont['OS/2'].usWinAscent
+      vmetrics['usWinDescent'][full_font_name] = ttFont['OS/2'].usWinDescent
+      vmetrics['ascent'][full_font_name] = ttFont['hhea'].ascent
+      vmetrics['descent'][full_font_name] = ttFont['hhea'].descent
+
+  for k, v in vmetrics.items():
+    metric_vals = set(vmetrics[k].values())
+    if len(metric_vals) != 1:
+      warn.append(k)
+
+  if warn:
+    for k in warn:
+      s = ["{}: {}".format(k, v) for k, v in vmetrics[k].items()]
+      s = "\n".join(s)
+      yield WARN, (f"{k} is not the same across the super-family:\n"
+                   f"{s}")
+  else:
+    yield PASS, f"Vertical metrics are the same across the super-family."
 
 
 profile.auto_register(globals())
