@@ -18,23 +18,91 @@ import os
 from fontTools.ttLib import TTFont
 from typing import Text, Optional
 
+def text_flow(content, width=80, indent=0, left_margin=0,
+              space_padding=False, text_color="{}".format):
+  result = ""
+  for line in content.split("\n"):
+    if line.strip() == "":
+      if space_padding:
+        result += " " * indent + text_color(" " * width)
+      result += "\n"
+      continue
+
+    words = line.split(" ")
+    while words:
+      this_line = " " * left_margin + words.pop(0)
+
+      if len(this_line) > width:
+        # let's see what we can do to make it fit
+        if "/" in this_line:
+          # here we feed-back chunks of a URL
+          # into words if it overflows the block
+          chunks = this_line.split('/')
+          new_line = chunks.pop(0)
+          while chunks:
+            if len(new_line) + 1 + len(chunks[0]) >= width: break
+            new_line += "/" + chunks.pop(0)
+          this_line = new_line
+          words.insert(0, "/" + "/".join(chunks))
+        else:
+          # not sure what else to do,
+          # so we'll simply cut the long word
+          words.insert(0, this_line[width:])
+          this_line = this_line[:width]
+
+      while words and (len(this_line) + 1 + len(words[0]) < width or
+                       len(words[0]) >= width):
+        this_line += " " + words.pop(0)
+
+      if space_padding:
+        # pad the line with spaces to fit the block width:
+        this_line += " " * (width - len(this_line))
+      result += " " * indent + text_color(this_line) + "\n"
+  return result
+
+
+def unindent_rationale(rationale, checkid=None):
+  content = ""
+  for line in rationale.split("\n"):
+    if line.strip() == "":
+      content += "\n"
+      continue
+
+    if checkid and line[:4].strip() != "":
+      import sys
+      sys.exit(f"FATAL ERROR: The rationale metadata on '{checkid}' must be indented by 4 spaces!")
+
+    # all lines are assumed to be indented by 4 spaces
+    content += line[4:] + "\n"
+  return content
+
+
+def suffix(font):
+  filename = os.path.basename(font)
+  basename = os.path.splitext(filename)[0]
+  s = basename.split('-')
+  s.pop(0)
+  return '-'.join(s)
+
+
 def portable_path(p):
   return os.path.join(*p.split('/'))
 
+
 def TEST_FILE(f):
   return portable_path("data/test/" + f)
 
 
-def pretty_print_list(values, shorten=10, glue="and"):
+def pretty_print_list(values, shorten=10, sep=", ", glue="and"):
   if len(values) == 1:
     return str(values[0])
 
   if shorten and len(values) > shorten + 2:
-    return "{} {} {} more.".format(", ".join(map(str, values[:shorten])),
+    return "{} {} {} more.".format(sep.join(map(str, values[:shorten])),
                                    glue,
                                    len(values) - shorten)
   else:
-    return "{} {} {}".format(", ".join(map(str, values[:-1])),
+    return "{} {} {}".format(sep.join(map(str, values[:-1])),
                              glue,
                              str(values[-1]))
 
@@ -184,7 +252,7 @@ def check_bit_entry(ttFont, table, attr, expected, bitmask, bitname):
     if expected:
       expected_str = "set"
     else:
-      expected_str = "reset"
+      expected_str = "unset"
     return FAIL, Message(f"bad-{bitname}",
                          f"{name_str} should be {expected_str}.")
 
@@ -242,6 +310,50 @@ def ttf_glyph_has_ink(font: TTFont, name: Text) -> bool:
   return False
 
 
+def unicoderange_bit_name(bit):
+  from fontbakery.constants import UNICODERANGE_DATA
+  return UNICODERANGE_DATA[bit][0][1]
+
+
+def get_preferred_cmap(ttFont):
+  cmaps = {}
+  for table in ttFont["cmap"].tables:
+    cmaps[table.format] = table.cmap
+
+  if 12 in cmaps:
+    return cmaps[12]
+
+  elif 4 in cmaps:
+    return cmaps[4]
+
+  else:
+    return None
+
+
+def chars_in_range(ttFont, bit):
+  from fontbakery.constants import UNICODERANGE_DATA
+  cmap = get_preferred_cmap(ttFont)
+  chars = []
+  for c in sorted(cmap):
+    for entry in UNICODERANGE_DATA[bit]:
+      if c >= entry[2] and c <= entry[3]:
+        chars.append(c)
+  return chars
+
+
+def compute_unicoderange_bits(ttFont):
+  from fontbakery.constants import UNICODERANGE_DATA
+  cmap = get_preferred_cmap(ttFont)
+  result = 0
+  for c in sorted(cmap):
+    for bit in range(len(UNICODERANGE_DATA)):
+      for entry in UNICODERANGE_DATA[bit]:
+        bit = entry[0]
+        if c >= entry[2] and c <= entry[3]:
+          result |= (1 << bit)
+  return result
+
+
 def glyph_has_ink(font: TTFont, name: Text) -> bool:
   """Checks if specified glyph has any ink.
 
@@ -268,7 +380,7 @@ def assert_results_contain(check_results, expected_status, expected_msgcode=None
   order among other log messages.
   """
   found = False
-  for status, message in check_results:
+  for status, message in list(check_results):
     if status == expected_status and message.code == expected_msgcode:
       found = True
       break
