@@ -4,19 +4,17 @@ import fontTools.ttLib
 from fontTools.ttLib import TTFont
 
 from fontbakery.utils import TEST_FILE, portable_path
-from fontbakery.constants import NameID, PlatformID, WindowsEncodingID, ENGLISH_LANG_ID
-from fontbakery.checkrunner import (
-              DEBUG
-            , INFO
-            , WARN
-            , ERROR
-            , SKIP
-            , PASS
-            , FAIL
-            )
+from fontbakery.constants import (NameID,
+                                  PlatformID,
+                                  WindowsEncodingID,
+                                  WindowsLanguageID,
+                                  MacintoshEncodingID,
+                                  MacintoshLanguageID)
+from fontbakery.checkrunner import (DEBUG, INFO, WARN, ERROR, SKIP, PASS, FAIL)
 
 check_statuses = (ERROR, FAIL, SKIP, PASS, WARN, INFO, DEBUG)
 
+
 def test_check_name_empty_records():
     from fontbakery.profiles.name import com_adobe_fonts_check_name_empty_records as check
 
@@ -30,12 +28,12 @@ def test_check_name_empty_records():
     # now try a completely empty string
     test_font['name'].names[3].string = b''
     status, message = list(check(test_font))[-1]
-    assert status == FAIL
+    assert status == FAIL and message.code == "empty-record"
 
     # now try a string that only has whitespace
     test_font['name'].names[3].string = b' '
     status, message = list(check(test_font))[-1]
-    assert status == FAIL
+    assert status == FAIL and message.code == "empty-record"
 
 
 def test_check_name_no_copyright_on_description():
@@ -57,7 +55,7 @@ def test_check_name_no_copyright_on_description():
 
   print('Test FAIL with a bad font...')
   status, message = list(check(ttFont))[-1]
-  assert status == FAIL
+  assert status == FAIL and message.code == "copyright-on-description"
 
 
 # If we ever reuse this helper function,
@@ -156,27 +154,6 @@ def test_check_monospace():
     assert results_contain(results, FAIL, "mono-bad-panose-proportion")
 
 
-def test_check_name_line_breaks():
-  """ Name table entries should not contain line-breaks. """
-  from fontbakery.profiles.name import com_google_fonts_check_name_line_breaks as check
-
-  # Our reference Mada Regular font is good here:
-  ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
-
-  # So it must PASS the check:
-  print ("Test PASS with a good font...")
-  status, message = list(check(ttFont))[-1]
-  assert status == PASS
-
-  print ("Test FAIL with name entries containing a linebreak...")
-  for i in range(len(ttFont["name"].names)):
-    ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
-    encoding = ttFont["name"].names[i].getEncoding()
-    ttFont["name"].names[i].string = "bad\nstring".encode(encoding)
-    status, message = list(check(ttFont))[-1]
-    assert status == FAIL
-
-
 def test_check_name_match_familyname_fullfont():
   """ Does full font name begin with the font family name? """
   from fontbakery.profiles.name import com_google_fonts_check_name_match_familyname_fullfont as check
@@ -214,7 +191,7 @@ def test_check_name_match_familyname_fullfont():
   status, message = list(check(ttFont))[-1]
   assert status == FAIL and message.code == "no-font-family-name"
 
-def assert_name_table_check_result(ttFont, index, name, check, value, expected_result):
+def assert_name_table_check_result(ttFont, index, name, check, value, expected_result, expected_keyword=None):
   backup = name.string
   # set value
   ttFont["name"].names[index].string = value.encode(name.getEncoding())
@@ -223,6 +200,8 @@ def assert_name_table_check_result(ttFont, index, name, check, value, expected_r
   # restore value
   ttFont["name"].names[index].string = backup
   assert status == expected_result
+  if expected_keyword:
+    assert message.code == expected_keyword
 
 
 def test_check_family_naming_recommendations():
@@ -239,15 +218,15 @@ def test_check_family_naming_recommendations():
   # We'll test rule violations in all entries one-by-one
   for index, name in enumerate(ttFont["name"].names):
     # and we'll test all INFO/PASS code-paths for each of the rules:
-    def name_test(value, expected):
-      assert_name_table_check_result(ttFont, index, name, check, value, expected) #pylint: disable=cell-var-from-loop
+    def name_test(value, expected, keyword=None):
+      assert_name_table_check_result(ttFont, index, name, check, value, expected, keyword) #pylint: disable=cell-var-from-loop
 
     if name.nameID == NameID.POSTSCRIPT_NAME:
       print ("== NameID.POST_SCRIPT_NAME ==")
 
       print ("Test INFO: May contain only a-zA-Z0-9 characters and an hyphen...")
       # The '@' and '!' chars here are the expected rule violations:
-      name_test("B@zinga!", INFO)
+      name_test("B@zinga!", INFO, "bad-entries")
 
       print ("Test PASS: A name with a single hyphen is OK...")
       # A single hypen in the name is OK:
@@ -255,19 +234,19 @@ def test_check_family_naming_recommendations():
 
       print ("Test INFO: May not contain more than a single hyphen...")
       # The second hyphen char here is the expected rule violation:
-      name_test("Big-Bang-Theory", INFO)
+      name_test("Big-Bang-Theory", INFO, "bad-entries")
 
-      print ("Test INFO: Exceeds max length (29)...")
-      name_test("A"*30, INFO)
+      print ("Test INFO: Exceeds max length (63)...")
+      name_test("A"*64, INFO, "bad-entries")
 
-      print ("Test PASS: Does not exceeds max length...")
-      name_test("A"*29, PASS)
+      print ("Test PASS: Does not exceed max length...")
+      name_test("A"*63, PASS)
 
     elif name.nameID == NameID.FULL_FONT_NAME:
       print ("== NameID.FULL_FONT_NAME ==")
 
       print ("Test INFO: Exceeds max length (63)...")
-      name_test("A"*64, INFO)
+      name_test("A"*64, INFO, "bad-entries")
 
       print ("Test PASS: Does not exceeds max length...")
       name_test("A"*63, PASS)
@@ -276,7 +255,7 @@ def test_check_family_naming_recommendations():
       print ("== NameID.FONT_FAMILY_NAME ==")
 
       print ("Test INFO: Exceeds max length (31)...")
-      name_test("A"*32, INFO)
+      name_test("A"*32, INFO, "bad-entries")
 
       print ("Test PASS: Does not exceeds max length...")
       name_test("A"*31, PASS)
@@ -285,7 +264,7 @@ def test_check_family_naming_recommendations():
       print ("== NameID.FONT_SUBFAMILY_NAME ==")
 
       print ("Test INFO: Exceeds max length (31)...")
-      name_test("A"*32, INFO)
+      name_test("A"*32, INFO, "bad-entries")
 
       print ("Test PASS: Does not exceeds max length...")
       name_test("A"*31, PASS)
@@ -294,7 +273,7 @@ def test_check_family_naming_recommendations():
       print ("== NameID.TYPOGRAPHIC_FAMILY_NAME ==")
 
       print ("Test INFO: Exceeds max length (31)...")
-      name_test("A"*32, INFO)
+      name_test("A"*32, INFO, "bad-entries")
 
       print ("Test PASS: Does not exceeds max length...")
       name_test("A"*31, PASS)
@@ -303,26 +282,12 @@ def test_check_family_naming_recommendations():
       print ("== NameID.FONT_TYPOGRAPHIC_SUBFAMILY_NAME ==")
 
       print ("Test INFO: Exceeds max length (31)...")
-      name_test("A"*32, INFO)
+      name_test("A"*32, INFO, "bad-entries")
 
       print ("Test PASS: Does not exceeds max length...")
       name_test("A"*31, PASS)
 
 
-def test_check_name_rfn():
-  """ Name table strings must not contain 'Reserved Font Name'. """
-  from fontbakery.profiles.name import com_google_fonts_check_name_rfn as check
-
-  test_font = TTFont(TEST_FILE("nunito/Nunito-Regular.ttf"))
-
-  status, _ = list(check(test_font))[-1]
-  assert status == PASS
-
-  test_font["name"].setName("Bla Reserved Font Name", 5, 3, 1, 0x409)
-  status, _ = list(check(test_font))[-1]
-  assert status == WARN
-
-
 def test_check_name_postscript_vs_cff():
   from fontbakery.profiles.name import com_adobe_fonts_check_name_postscript_vs_cff as check
   test_font = TTFont()
@@ -335,17 +300,17 @@ def test_check_name_postscript_vs_cff():
     NameID.POSTSCRIPT_NAME,
     PlatformID.WINDOWS,
     WindowsEncodingID.UNICODE_BMP,
-    ENGLISH_LANG_ID
+    WindowsLanguageID.ENGLISH_USA
   )
   status, message = list(check(test_font))[-1]
-  assert status == FAIL
+  assert status == FAIL and message.code == "mismatch"
 
   test_font['name'].setName(
     'SomeFontName',
     NameID.POSTSCRIPT_NAME,
     PlatformID.WINDOWS,
     WindowsEncodingID.UNICODE_BMP,
-    ENGLISH_LANG_ID
+    WindowsLanguageID.ENGLISH_USA
   )
   status, message = list(check(test_font))[-1]
   assert status == PASS
@@ -365,8 +330,8 @@ def test_check_name_postscript_name_consistency():
     'SourceSansPro-Regular',
     NameID.POSTSCRIPT_NAME,
     PlatformID.MACINTOSH,
-    WindowsEncodingID.UNICODE_BMP,
-    ENGLISH_LANG_ID
+    MacintoshEncodingID.ROMAN,
+    MacintoshLanguageID.ENGLISH
   )
   status, message = list(check(test_font))[-1]
   assert status == PASS
@@ -376,11 +341,11 @@ def test_check_name_postscript_name_consistency():
     'YetAnotherFontName',
     NameID.POSTSCRIPT_NAME,
     PlatformID.MACINTOSH,
-    WindowsEncodingID.UNICODE_BMP,
-    ENGLISH_LANG_ID
+    MacintoshEncodingID.ROMAN,
+    MacintoshLanguageID.ENGLISH
   )
   status, message = list(check(test_font))[-1]
-  assert status == FAIL
+  assert status == FAIL and message.code == "inconsistency"
 
 
 def test_check_family_max_4_fonts_per_family_name():
@@ -420,4 +385,4 @@ def test_check_family_max_4_fonts_per_family_name():
         name_record.string = 'foobar'.encode('utf-16be')
 
   status, message = list(check(test_fonts))[-1]
-  assert status == FAIL
+  assert status == FAIL and message.code == "too-many"
