@@ -45,334 +45,31 @@ def montserrat_ttFonts():
   return [TTFont(path) for path in paths]
 
 
-def test_check_family_single_directory():
-  """ Fonts are all in the same directory. """
-  from fontbakery.profiles.universal import com_google_fonts_check_family_single_directory as check
-  same_dir = [
-    TEST_FILE("cabin/Cabin-Thin.ttf"),
-    TEST_FILE("cabin/Cabin-ExtraLight.ttf")
-  ]
-  multiple_dirs = [
-    TEST_FILE("mada/Mada-Regular.ttf"),
-    TEST_FILE("cabin/Cabin-ExtraLight.ttf")
-  ]
-  print(f'Test PASS with same dir: {same_dir}')
-  status, message = list(check(same_dir))[-1]
-  assert status == PASS
+cabin_fonts = [
+  TEST_FILE("cabin/Cabin-BoldItalic.ttf"),
+  TEST_FILE("cabin/Cabin-Bold.ttf"),
+  TEST_FILE("cabin/Cabin-Italic.ttf"),
+  TEST_FILE("cabin/Cabin-MediumItalic.ttf"),
+  TEST_FILE("cabin/Cabin-Medium.ttf"),
+  TEST_FILE("cabin/Cabin-Regular.ttf"),
+  TEST_FILE("cabin/Cabin-SemiBoldItalic.ttf"),
+  TEST_FILE("cabin/Cabin-SemiBold.ttf")
+]
 
-  print(f'Test FAIL with multiple dirs: {multiple_dirs}')
-  status, message = list(check(multiple_dirs))[-1]
-  assert status == FAIL
+cabin_condensed_fonts = [
+  TEST_FILE("cabin/CabinCondensed-Regular.ttf"),
+  TEST_FILE("cabin/CabinCondensed-Medium.ttf"),
+  TEST_FILE("cabin/CabinCondensed-Bold.ttf"),
+  TEST_FILE("cabin/CabinCondensed-SemiBold.ttf")
+]
 
+@pytest.fixture
+def cabin_ttFonts():
+  return [TTFont(path) for path in cabin_fonts]
 
-def test_check_ftxvalidator_is_available():
-  """ Is the command `ftxvalidator` (Apple Font Tool Suite) available? """
-  from fontbakery.profiles.universal import com_google_fonts_check_ftxvalidator_is_available as check
-
-  # code-paths:
-  # - PASS, "ftxvalidator is available."
-  # - WARN, "ftxvalidator is not available."
-  status, output = check(True)
-  assert status == PASS
-  assert "is available" in output
-
-  status, output = check(False)
-  assert status == WARN
-  assert "is not available" in output
-
-
-def NOT_IMPLEMENTED_test_check_ftxvalidator():
-  """ Checking with ftxvalidator. """
-  # from fontbakery.profiles.universal import com_google_fonts_check_ftxvalidator as check
-  # TODO: Implement-me!
-  #
-  # code-paths:
-  # - PASS, "ftxvalidator passed this file."
-  # - FAIL, "ftxvalidator outputs to stderr."
-  # - ERROR, "ftxvalidator returned an error code."
-  # - ERROR, "ftxvalidator is not available!"
-
-
-def test_check_ots():
-  """ Checking with ots-sanitize. """
-  from fontbakery.profiles.universal import com_google_fonts_check_ots as check
-
-  sanitary_font = TEST_FILE("cabin/Cabin-Regular.ttf")
-  status, _ = list(check(sanitary_font))[-1]
-  assert status == PASS
-
-  bogus_font = TEST_FILE("README.txt")
-  status, output = list(check(bogus_font))[-1]
-  assert status == FAIL
-  assert "invalid version tag" in output
-  assert "Failed to sanitize file!" in output
-
-
-def NOT_IMPLEMENTED_test_check_fontforge_stderr():
-  """ FontForge validation outputs error messages? """
-  # from fontbakery.profiles.universal import com_google_fonts_check_fontforge_error_messages as check
-  # TODO: Implement-me!
-  #
-  # code-paths:
-  # WARN, "Fontforge printed messages to stderr."
-  # PASS, "Fontforge validation did not output any error message."
-
-
-def NOT_IMPLEMENTED_test_check_fontforge():
-  """ FontForge checks. """
-  # from fontbakery.profiles.universal import com_google_fonts_check_fontforge as check
-  # TODO: Implement-me!
-  #
-  # code-paths:
-  # - PASS
-  # - SKIP
-  # - FAIL, "Contours are not closed!"
-  # - FAIL, "There are countour intersections!"
-  # - FAIL, "Contours have incorrect directions!"
-  # - FAIL, "References in the glyph have been flipped!"
-  # - FAIL, "Glyphs do not have points at extremas!"
-  # - FAIL, "Glyph names referred to from glyphs not present in the font!"
-  # - FAIL, "Points (or control points) are too far apart!"
-  # - FAIL, "There are glyphs with more than 1,500 points! Exceeds a PostScript limit."
-  # - FAIL, "Exceeds PostScript limit of 96 hints per glyph"
-  # - FAIL, "Font has invalid glyph names!"
-  # - FAIL, "Glyphs exceed allowed numbers of points defined in maxp"
-  # - FAIL, "Glyphs exceed allowed numbers of paths defined in maxp!"
-  # - FAIL, Composite glyphs exceed allowed numbers of points defined in maxp!"
-  # - FAIL, "Composite glyphs exceed allowed numbers of paths defined in maxp!"
-  # - FAIL, "Glyphs instructions have invalid lengths!"
-  # - FAIL, "Points in glyphs are not integer aligned!"
-  # - FAIL, "Glyphs do not have all required anchors!"
-  # - FAIL, "Glyph names are not unique!"
-  # - FAIL, "Unicode code points are not unique!"
-  # - FAIL, "Hints should NOT overlap!"
-
-
-def test_check_mandatory_glyphs():
-  """ Font contains the first few mandatory glyphs (.null or NULL, CR and
-  space)? """
-  from fontbakery.profiles.universal import com_google_fonts_check_mandatory_glyphs as check
-
-  test_font = TTFont(TEST_FILE("nunito/Nunito-Regular.ttf"))
-  status, _ = list(check(test_font))[-1]
-  assert status == PASS
-
-  import fontTools.subset
-  subsetter = fontTools.subset.Subsetter()
-  subsetter.populate(glyphs="n")  # Arbitrarily remove everything except n.
-  subsetter.subset(test_font)
-  status, _ = list(check(test_font))[-1]
-  assert status == WARN
-
-
-def test_check_whitespace_glyphs():
-  """ Font contains glyphs for whitespace characters ? """
-  from fontbakery.profiles.universal import com_google_fonts_check_whitespace_glyphs as check
-  from fontbakery.profiles.shared_conditions import missing_whitespace_chars
-
-  # Our reference Mada Regular font is good here:
-  ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
-  missing = missing_whitespace_chars(ttFont)
-
-  # So it must PASS the check:
-  print ("Test PASS with a good font...")
-  status, message = list(check(ttFont, missing))[-1]
-  assert status == PASS
-
-  # Then we remove the nbsp char (0x00A0) so that we get a FAIL:
-  print ("Test FAIL with a font lacking a nbsp (0x00A0)...")
-  for table in ttFont['cmap'].tables:
-    if 0x00A0 in table.cmap:
-      del table.cmap[0x00A0]
-
-  missing = missing_whitespace_chars(ttFont)
-  status, message = list(check(ttFont, missing))[-1]
-  assert status == FAIL
-
-  # restore original Mada Regular font:
-  ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
-
-  # And finally remove the space character (0x0020) to get another FAIL:
-  print ("Test FAIL with a font lacking a space (0x0020)...")
-  for table in ttFont['cmap'].tables:
-    if 0x00A0 in table.cmap:
-      del table.cmap[0x00A0]
-
-  missing = missing_whitespace_chars(ttFont)
-  status, message = list(check(ttFont, missing))[-1]
-  assert status == FAIL
-
-
-def test_check_whitespace_glyphnames():
-  """ Font has **proper** whitespace glyph names ? """
-  from fontbakery.profiles.universal import com_google_fonts_check_whitespace_glyphnames as check
-
-  def deleteGlyphEncodings(font, cp):
-    """ This routine is used on to introduce errors
-        in a given font by removing specific entries
-        in the cmap tables.
-    """
-    for subtable in font['cmap'].tables:
-      if subtable.isUnicode():
-        subtable.cmap = {
-            codepoint: name for codepoint, name in subtable.cmap.items()
-            if codepoint != cp
-        }
-
-  # Our reference Mada Regular font is good here:
-  ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
-
-  # So it must PASS the check:
-  print ("Test PASS with a good font...")
-  status, message = list(check(ttFont))[-1]
-  assert status == PASS
-
-  print ("Test SKIP with post.formatType == 3.0 ...")
-  value = ttFont["post"].formatType
-  ttFont["post"].formatType = 3.0
-  status, message = list(check(ttFont))[-1]
-  assert status == SKIP
-  # and restore good value:
-  ttFont["post"].formatType = value
-
-  print ("Test FAIL with bad glyph name for char 0x0020 ...")
-  deleteGlyphEncodings(ttFont, 0x0020)
-  status, message = list(check(ttFont))[-1]
-  assert status == FAIL and message.code == "bad20"
-
-  # restore the original font object in preparation for the next test-case:
-  ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
-
-  print ("Test FAIL with bad glyph name for char 0x00A0 ...")
-  deleteGlyphEncodings(ttFont, 0x00A0)
-  status, message = list(check(ttFont))[-1]
-  assert status == FAIL and message.code == "badA0"
-
-
-def test_check_whitespace_ink():
-  """ Whitespace glyphs have ink? """
-  from fontbakery.profiles.universal import com_google_fonts_check_whitespace_ink as check
-
-  test_font = TTFont(TEST_FILE("nunito/Nunito-Regular.ttf"))
-  status, _ = list(check(test_font))[-1]
-  assert status == PASS
-
-  print ("Test for whitespace character having composites (with ink).")
-  test_font["cmap"].tables[0].cmap[0x0020] = "uni1E17"
-  status, _ = list(check(test_font))[-1]
-  assert status == FAIL
-
-  print ("Test for whitespace character having outlines (with ink).")
-  test_font["cmap"].tables[0].cmap[0x0020] = "scedilla"
-  status, _ = list(check(test_font))[-1]
-  assert status == FAIL
-
-  print ("Test for whitespace character having composites (without ink).")
-  import fontTools.pens.ttGlyphPen
-  pen = fontTools.pens.ttGlyphPen.TTGlyphPen(test_font.getGlyphSet())
-  pen.addComponent("space", (1, 0, 0, 1, 0, 0))
-  test_font["glyf"].glyphs["uni200B"] = pen.glyph()
-  status, _ = list(check(test_font))[-1]
-  assert status == FAIL
-
-
-def test_check_required_tables():
-  """ Font contains all required tables ? """
-  from fontbakery.profiles.universal import com_google_fonts_check_required_tables as check
-
-  required_tables = ["cmap", "head", "hhea", "hmtx",
-                     "maxp", "name", "OS/2", "post"]
-  optional_tables = ["cvt ", "fpgm", "loca", "prep",
-                     "VORG", "EBDT", "EBLC", "EBSC",
-                     "BASE", "GPOS", "GSUB", "JSTF",
-                     "DSIG", "gasp", "hdmx", "kern",
-                     "LTSH", "PCLT", "VDMX", "vhea",
-                     "vmtx"]
-  # Our reference Mada Regular font is good here
-  ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
-
-  # So it must PASS the check:
-  print ("Test PASS with a good font...")
-  status, message = list(check(ttFont))[-1]
-  assert status == PASS
-
-  # Now we test the special cases for variable fonts:
-
-  print ("Test FAIL with fvar but no STAT...")
-  # Note: A TTF with an fvar table but no STAT table
-  #       is probably a GX font. For now we're OK with
-  #       rejecting those by emitting a FAIL in this case.
-  #
-  # TODO: Maybe we could someday emit a more explicit
-  #       message to the users regarding that...
-  ttFont.reader.tables["fvar"] = "foo"
-  status, message = list(check(ttFont))[-1]
-  assert status == FAIL
-
-  print ("Test PASS with STAT on a non-variable font...")
-  del ttFont.reader.tables["fvar"]
-  ttFont.reader.tables["STAT"] = "foo"
-  status, message = list(check(ttFont))[-1]
-  assert status == PASS
-
-  # and finally remove what we've just added:
-  del ttFont.reader.tables["STAT"]
-  # Now we remove required tables one-by-one to validate the FAIL code-path:
-  for required in required_tables:
-    print (f"Test FAIL with missing mandatory table {required} ...")
-    ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
-    if required in ttFont.reader.tables:
-      del ttFont.reader.tables[required]
-    status, message = list(check(ttFont))[-1]
-    assert status == FAIL
-
-  # Then, in preparation for the next step, we make sure
-  # there's no optional table (by removing them all):
-  for optional in optional_tables:
-    if optional in ttFont.reader.tables:
-      del ttFont.reader.tables[optional]
-
-  # Then re-insert them one by one to validate the INFO code-path:
-  for optional in optional_tables:
-    print (f"Test INFO with optional table {required} ...")
-    ttFont.reader.tables[optional] = "foo"
-    # and ensure that the second to last logged message is an
-    # INFO status informing the user about it:
-    status, message = list(check(ttFont))[-2]
-    assert status == INFO
-    # remove the one we've just inserted before trying the next one:
-    del ttFont.reader.tables[optional]
-
-
-def test_check_unwanted_tables():
-  """ Are there unwanted tables ? """
-  from fontbakery.profiles.universal import com_google_fonts_check_unwanted_tables as check
-
-  unwanted_tables = [
-    "FFTM", # FontForge
-    "TTFA", # TTFAutohint
-    "TSI0", # TSI* = VTT
-    "TSI1",
-    "TSI2",
-    "TSI3",
-    "TSI5",
-    "prop" # FIXME: Why is this one unwanted?
-  ]
-  # Our reference Mada Regular font is good here:
-  ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
-
-  # So it must PASS the check:
-  print ("Test PASS with a good font...")
-  status, message = list(check(ttFont))[-1]
-  assert status == PASS
-
-  # We now add unwanted tables one-by-one to validate the FAIL code-path:
-  for unwanted in unwanted_tables:
-    print (f"Test FAIL with unwanted table {unwanted} ...")
-    ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
-    ttFont.reader.tables[unwanted] = "foo"
-    status, message = list(check(ttFont))[-1]
-    assert status == FAIL
+@pytest.fixture
+def cabin_condensed_ttFonts():
+  return [TTFont(path) for path in cabin_condensed_fonts]
 
 
 def test_check_valid_glyphnames():
@@ -380,26 +77,45 @@ def test_check_valid_glyphnames():
   import io
   from fontbakery.profiles.universal import com_google_fonts_check_valid_glyphnames as check
 
+  # We start with a good font file:
   test_font_path = TEST_FILE("nunito/Nunito-Regular.ttf")
   test_font = TTFont(test_font_path)
   status, _ = list(check(test_font))[-1]
   assert status == PASS
 
-  bad_name1 = "a" * 32
+  # There used to be a 31 char max-length limit.
+  # This was good:
+  test_font.glyphOrder[2] = "a" * 31
+  status, _ = list(check(test_font))[-1]
+  assert status == PASS
+
+  # And this was bad:
+  legacy_too_long = "a" * 32
+  test_font.glyphOrder[2] = legacy_too_long
+  status, msg = list(check(test_font))[-1]
+  assert status == WARN and msg.code == "legacy-long-names"
+  assert legacy_too_long in msg.message
+
+  # Nowadays, it seems most implementations can deal with
+  # up to 63 char glyph names:
+  good_name = "b" * 63
+  bad_name1 = "a" * 64
   bad_name2 = "3cents"
   bad_name3 = ".threecents"
-  good_name1 = "b" * 31
   test_font.glyphOrder[2] = bad_name1
   test_font.glyphOrder[3] = bad_name2
   test_font.glyphOrder[4] = bad_name3
-  test_font.glyphOrder[5] = good_name1
-  status, message = list(check(test_font))[-1]
-  assert status == FAIL
-  assert bad_name1 in message
-  assert bad_name2 in message
-  assert bad_name3 in message
-  assert good_name1 not in message
+  test_font.glyphOrder[5] = good_name
+  status, msg = list(check(test_font))[-1]
+  assert status == FAIL and msg.code == "found-invalid-names"
+  assert good_name not in msg.message
+  assert bad_name1 in msg.message
+  assert bad_name2 in msg.message
+  assert bad_name3 in msg.message
 
+  # TrueType fonts with a format 3.0 post table contain
+  # no glyph names, so the check must be SKIP'd in that case.
+  #
   # Upgrade to post format 3.0 and roundtrip data to update TTF object.
   test_font = TTFont(test_font_path)
   test_font["post"].formatType = 3.0
@@ -588,16 +304,13 @@ def test_check_ftxvalidator_is_available():
   """ Is the command `ftxvalidator` (Apple Font Tool Suite) available? """
   from fontbakery.profiles.universal import com_google_fonts_check_ftxvalidator_is_available as check
 
-  # code-paths:
-  # - PASS, "ftxvalidator is available."
-  # - WARN, "ftxvalidator is not available."
-  status, output = check(True)
+  status, output = list(check("/usr/local/bin/ftxvalidator"))[-1]
   assert status == PASS
   assert "is available" in output
 
-  status, output = check(False)
+  status, output = list(check(None))[-1]
   assert status == WARN
-  assert "is not available" in output
+  assert "Could not find" in output
 
 
 def NOT_IMPLEMENTED_test_check_ftxvalidator():
@@ -627,46 +340,6 @@ def test_check_ots():
   assert "Failed to sanitize file!" in output
 
 
-def NOT_IMPLEMENTED_test_check_fontforge_stderr():
-  """ FontForge validation outputs error messages? """
-  # from fontbakery.profiles.universal import com_google_fonts_check_fontforge_error_messages as check
-  # TODO: Implement-me!
-  #
-  # code-paths:
-  # WARN, "Fontforge printed messages to stderr."
-  # PASS, "Fontforge validation did not output any error message."
-
-
-def NOT_IMPLEMENTED_test_check_fontforge():
-  """ FontForge checks. """
-  # from fontbakery.profiles.universal import com_google_fonts_check_fontforge as check
-  # TODO: Implement-me!
-  #
-  # code-paths:
-  # - PASS
-  # - SKIP
-  # - FAIL, "Contours are not closed!"
-  # - FAIL, "There are countour intersections!"
-  # - FAIL, "Contours have incorrect directions!"
-  # - FAIL, "References in the glyph have been flipped!"
-  # - FAIL, "Glyphs do not have points at extremas!"
-  # - FAIL, "Glyph names referred to from glyphs not present in the font!"
-  # - FAIL, "Points (or control points) are too far apart!"
-  # - FAIL, "There are glyphs with more than 1,500 points! Exceeds a PostScript limit."
-  # - FAIL, "Exceeds PostScript limit of 96 hints per glyph"
-  # - FAIL, "Font has invalid glyph names!"
-  # - FAIL, "Glyphs exceed allowed numbers of points defined in maxp"
-  # - FAIL, "Glyphs exceed allowed numbers of paths defined in maxp!"
-  # - FAIL, Composite glyphs exceed allowed numbers of points defined in maxp!"
-  # - FAIL, "Composite glyphs exceed allowed numbers of paths defined in maxp!"
-  # - FAIL, "Glyphs instructions have invalid lengths!"
-  # - FAIL, "Points in glyphs are not integer aligned!"
-  # - FAIL, "Glyphs do not have all required anchors!"
-  # - FAIL, "Glyph names are not unique!"
-  # - FAIL, "Unicode code points are not unique!"
-  # - FAIL, "Hints should NOT overlap!"
-
-
 def test_check_mandatory_glyphs():
   """ Font contains the first few mandatory glyphs (.null or NULL, CR and
   space)? """
@@ -706,7 +379,7 @@ def test_check_whitespace_glyphs():
 
   missing = missing_whitespace_chars(ttFont)
   status, message = list(check(ttFont, missing))[-1]
-  assert status == FAIL
+  assert status == FAIL and message.code == "missing-whitespace-glyphs"
 
   # restore original Mada Regular font:
   ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
@@ -719,7 +392,7 @@ def test_check_whitespace_glyphs():
 
   missing = missing_whitespace_chars(ttFont)
   status, message = list(check(ttFont, missing))[-1]
-  assert status == FAIL
+  assert status == FAIL and message.code == "missing-whitespace-glyphs"
 
 
 def test_check_whitespace_glyphnames():
@@ -875,7 +548,8 @@ def test_check_unwanted_tables():
     "TSI2",
     "TSI3",
     "TSI5",
-    "prop" # FIXME: Why is this one unwanted?
+    "prop", # FIXME: Why is this one unwanted?
+    "MVAR", # Bugs in DirectWrite
   ]
   # Our reference Mada Regular font is good here:
   ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
@@ -1003,3 +677,16 @@ def test_check_family_vertical_metrics(montserrat_ttFonts):
   montserrat_ttFonts[0]['OS/2'].usWinAscent = 4000
   status, message = list(check(montserrat_ttFonts))[-1]
   assert status == FAIL
+
+
+def test_check_superfamily_vertical_metrics(montserrat_ttFonts, cabin_ttFonts, cabin_condensed_ttFonts):
+  from fontbakery.profiles.universal import com_google_fonts_check_superfamily_vertical_metrics as check
+  print("Test pass with multiple good families...")
+  status, message = list(check([cabin_ttFonts,
+                                cabin_condensed_ttFonts]))[-1]
+  assert status == PASS
+
+  print("Test fail with families that diverge on vertical metric values...")
+  status, message = list(check([cabin_ttFonts,
+                                montserrat_ttFonts]))[-1]
+  assert status == WARN
